@@ -33,7 +33,7 @@ class KateFileTreePlugin : public KTextEditor::Plugin
     Q_OBJECT
 
 public:
-    explicit KateFileTreePlugin(QObject *parent = nullptr, const QList<QVariant> & = QList<QVariant>());
+    explicit KateFileTreePlugin(QObject *parent = nullptr, const QVariantList & = QVariantList());
     ~KateFileTreePlugin() override;
 
     QObject *createView(KTextEditor::MainWindow *mainWindow) override;
