@@ -17,20 +17,6 @@
 
 #include <KTextEditor/Editor>
 
-// TODO: Move to KTextEditor::Document
-static QString cursorToOffset(KTextEditor::Document *doc, KTextEditor::Cursor c)
-{
-    if (doc) {
-        int o = 0;
-        for (int i = 0; i < c.line(); ++i) {
-            o += doc->lineLength(i) + 1; // + 1 for \n
-        }
-        o += c.column();
-        return QString::number(o);
-    }
-    return {};
-}
-
 static QStringList readCommandFromJson(const QJsonObject &o)
 {
     const auto arr = o.value(QStringLiteral("command")).toArray();
@@ -178,11 +164,11 @@ void AbstractFormatter::onResultReady(const RunOutput &o)
 QStringList ClangFormat::args(KTextEditor::Document *doc) const
 {
     QString file = doc->url().toLocalFile();
-    const QString offset = cursorToOffset(m_doc, m_pos);
+    int off = m_doc->cursorToOffset(m_pos);
     QStringList args;
-    if (!offset.isEmpty()) {
+    if (off != -1) {
         const_cast<ClangFormat *>(this)->m_withCursor = true;
-        args << QStringLiteral("--cursor=%1").arg(offset);
+        args << QStringLiteral("--cursor=%1").arg(off);
     }
 
     args << QStringLiteral("--assume-filename=%1").arg(filenameFromMode(doc));
@@ -251,9 +237,6 @@ void RustFormat::onResultReady(const RunOutput &out)
         return;
     }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    auto iface = qobject_cast<KTextEditor::MovingInterface *>(m_doc);
-#endif
     std::vector<PatchLine> patch;
     const auto lines = out.out.split('\n');
     for (int i = 0; i < lines.size(); ++i) {
@@ -297,11 +280,8 @@ void RustFormat::onResultReady(const RunOutput &out)
             } else if (hl.startsWith(('-'))) {
                 PatchLine p;
                 p.type = PatchLine::Remove;
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
                 p.pos = m_doc->newMovingCursor(KTextEditor::Cursor(srcline, 0));
-#else
-                p.pos = iface->newMovingCursor(KTextEditor::Cursor(srcline, 0));
-#endif
+
                 patch.push_back(p);
                 srcline++;
             } else if (hl.startsWith("Diff in")) {
@@ -395,19 +375,14 @@ void PrettierFormat::run(KTextEditor::Document *doc)
     o[QStringLiteral("filePath")] = path;
     o[QStringLiteral("stdinFilePath")] = filenameFromMode(doc);
     o[QStringLiteral("source")] = originalText;
-    o[QStringLiteral("cursorOffset")] = cursorToOffset(doc, m_pos);
+    o[QStringLiteral("cursorOffset")] = doc->cursorToOffset(m_pos);
     s_nodeProcess->write(QJsonDocument(o).toJson(QJsonDocument::Compact) + '\0');
 }
 
 void GoFormat::onResultReady(const RunOutput &out)
 {
     if (out.exitCode == 0) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         const auto parsed = parseDiff(m_doc, QString::fromUtf8(out.out));
-#else
-        auto iface = qobject_cast<KTextEditor::MovingInterface *>(m_doc);
-        const auto parsed = parseDiff(iface, QString::fromUtf8(out.out));
-#endif
         Q_EMIT textFormattedPatch(m_doc, parsed);
     } else if (!out.err.isEmpty()) {
         Q_EMIT error(QString::fromUtf8(out.err));
