@@ -11,27 +11,27 @@
 
 #pragma once
 
-#include "advanced_settings.h"
-
-#include <QBoxLayout>
-#include <QCheckBox>
-#include <QComboBox>
-#include <QHash>
-#include <QJsonObject>
-#include <QLabel>
-#include <QLineEdit>
-#include <QResizeEvent>
-#include <QSpinBox>
-#include <QToolButton>
-#include <QVariantHash>
-#include <QWidget>
-#include <optional>
-#include <utility>
-
-#include <KActionCollection>
-#include <KConfigGroup>
-#include <KSelectAction>
 #include <KTextEditor/MainWindow>
+#include <QJsonObject>
+#include <QWidget>
+
+#include <optional>
+
+class AdvancedGDBSettings;
+class QPushButton;
+class QComboBox;
+class QFrame;
+class QSpinBox;
+class QResizeEvent;
+class QBoxLayout;
+class QCheckBox;
+class QLineEdit;
+class QLabel;
+class KSelectAction;
+class QToolButton;
+class KActionCollection;
+class KConfigGroup;
+class KatePluginGDB;
 
 struct GDBTargetConf {
     QString targetName;
@@ -63,7 +63,7 @@ class ConfigView : public QWidget
 public:
     enum TargetStringOrder { NameIndex = 0, ExecIndex, WorkDirIndex, ArgsIndex, GDBIndex, CustomStartIndex };
 
-    ConfigView(QWidget *parent, KTextEditor::MainWindow *mainWin);
+    ConfigView(QWidget *parent, KTextEditor::MainWindow *mainWin, KatePluginGDB *plugin);
     ~ConfigView() override;
 
 public:
@@ -77,6 +77,7 @@ public:
     bool takeFocusAlways() const;
     bool showIOTab() const;
     bool debuggerIsGDB() const;
+    QUrl dapConfigPath;
 
 Q_SIGNALS:
     void showIO(bool show);
@@ -145,4 +146,5 @@ private:
     QHash<QString, QHash<QString, DAPAdapterSettings>> m_dapAdapterSettings;
 
     AdvancedGDBSettings *m_advanced;
+    QUrl m_dapConfigPath;
 };
