@@ -25,7 +25,7 @@
 #include "plugin_katebuild.h"
 
 #include "AppOutput.h"
-
+#include "buildconfig.h"
 #include "hostprocess.h"
 
 #include <cassert>
@@ -37,6 +37,9 @@
 #include <QFileInfo>
 #include <QFontDatabase>
 #include <QIcon>
+#include <QJsonArray>
+#include <QJsonDocument>
+#include <QJsonObject>
 #include <QKeyEvent>
 #include <QRegularExpressionMatch>
 #include <QScrollBar>
@@ -170,6 +173,24 @@ QObject *KateBuildPlugin::createView(KTextEditor::MainWindow *mainWindow)
     return new KateBuildView(this, mainWindow);
 }
 
+/******************************************************************/
+int KateBuildPlugin::configPages() const
+{
+    return 1;
+}
+
+/******************************************************************/
+KTextEditor::ConfigPage *KateBuildPlugin::configPage(int number, QWidget *parent)
+{
+    if (number != 0) {
+        return nullptr;
+    }
+
+    KateBuildConfigPage *configPage = new KateBuildConfigPage(parent);
+    connect(configPage, &KateBuildConfigPage::configChanged, this, &KateBuildPlugin::configChanged);
+    return configPage;
+}
+
 /******************************************************************/
 KateBuildView::KateBuildView(KTextEditor::Plugin *plugin, KTextEditor::MainWindow *mw)
     : QObject(mw)
@@ -381,6 +402,34 @@ KateBuildView::KateBuildView(KTextEditor::Plugin *plugin, KTextEditor::MainWindo
 
     m_diagnosticsProvider.name = i18n("Build Information");
     m_diagnosticsProvider.setPersistentDiagnostics(true);
+
+    connect(&m_targetsUi->targetsModel, &TargetModel::projectTargetChanged, this, &KateBuildView::saveProjectTargets);
+    connect(m_targetsUi->moveTargetUp, &QToolButton::clicked, this, [this]() {
+        const QPersistentModelIndex &currentIndex = m_targetsUi->proxyModel.mapToSource(m_targetsUi->targetsView->currentIndex());
+        if (currentIndex.isValid()) {
+            m_targetsUi->targetsModel.moveRowUp(currentIndex);
+            if (currentIndex.data(TargetModel::IsProjectTargetRole).toBool() && currentIndex.data(TargetModel::RowTypeRole).toInt() != TargetModel::RootRow) {
+                saveProjectTargets();
+            }
+        }
+        m_targetsUi->targetsView->scrollTo(m_targetsUi->targetsView->currentIndex());
+    });
+    connect(m_targetsUi->moveTargetDown, &QToolButton::clicked, this, [this]() {
+        const QPersistentModelIndex &currentIndex = m_targetsUi->proxyModel.mapToSource(m_targetsUi->targetsView->currentIndex());
+        if (currentIndex.isValid()) {
+            m_targetsUi->targetsModel.moveRowDown(currentIndex);
+            if (currentIndex.data(TargetModel::IsProjectTargetRole).toBool() && currentIndex.data(TargetModel::RowTypeRole).toInt() != TargetModel::RootRow) {
+                saveProjectTargets();
+            }
+        }
+        m_targetsUi->targetsView->scrollTo(m_targetsUi->targetsView->currentIndex());
+    });
+
+    KateBuildPlugin *bPlugin = qobject_cast<KateBuildPlugin *>(plugin);
+    if (bPlugin) {
+        connect(bPlugin, &KateBuildPlugin::configChanged, this, &KateBuildView::readConfig);
+    }
+    readConfig();
 }
 
 /******************************************************************/
@@ -400,14 +449,16 @@ void KateBuildView::readSessionConfig(const KConfigGroup &cg)
 {
     int numTargets = cg.readEntry(QStringLiteral("NumTargets"), 0);
     m_projectTargetsetRow = cg.readEntry("ProjectTargetSetRow", 0);
-    m_targetsUi->targetsModel.clear();
+    m_targetsUi->targetsModel.clear(m_projectTargetsetRow > 0);
+
+    QModelIndex setIndex = m_targetsUi->targetsModel.sessionRootIndex();
 
     for (int i = 0; i < numTargets; i++) {
         QStringList targetNames = cg.readEntry(QStringLiteral("%1 Target Names").arg(i), QStringList());
         QString targetSetName = cg.readEntry(QStringLiteral("%1 Target").arg(i), QString());
         QString buildDir = cg.readEntry(QStringLiteral("%1 BuildPath").arg(i), QString());
 
-        QModelIndex index = m_targetsUi->targetsModel.addTargetSet(targetSetName, buildDir);
+        setIndex = m_targetsUi->targetsModel.insertTargetSetAfter(setIndex, targetSetName, buildDir);
 
         // Keep a bit of backwards compatibility by ensuring that the "default" target is the first in the list
         QString defCmd = cg.readEntry(QStringLiteral("%1 Target Default").arg(i), QString());
@@ -415,11 +466,12 @@ void KateBuildView::readSessionConfig(const KConfigGroup &cg)
         if (defIndex > 0) {
             targetNames.move(defIndex, 0);
         }
+        QModelIndex cmdIndex = setIndex;
         for (int tn = 0; tn < targetNames.size(); ++tn) {
             const QString &targetName = targetNames.at(tn);
             const QString &buildCmd = cg.readEntry(QStringLiteral("%1 BuildCmd %2").arg(i).arg(targetName));
             const QString &runCmd = cg.readEntry(QStringLiteral("%1 RunCmd %2").arg(i).arg(targetName));
-            m_targetsUi->targetsModel.addCommand(index, targetName, buildCmd, runCmd);
+            m_targetsUi->targetsModel.addCommandAfter(cmdIndex, targetName, buildCmd, runCmd);
         }
     }
 
@@ -455,18 +507,11 @@ void KateBuildView::writeSessionConfig(KConfigGroup &cg)
         }
     }
 
-    QList<TargetModel::TargetSet> targets = m_targetsUi->targetsModel.targetSets();
+    const QList<TargetModel::TargetSet> targets = m_targetsUi->targetsModel.sessionTargetSets();
 
     // Don't save project target-set, but save the row index
-    m_projectTargetsetRow = 0;
-    for (int i = 0; i < targets.size(); i++) {
-        if (i18n("Project Plugin Targets") == targets[i].name) {
-            m_projectTargetsetRow = i;
-            targets.removeAt(i);
-            break;
-        }
-    }
-
+    QModelIndex projRootIndex = m_targetsUi->targetsModel.projectRootIndex();
+    m_projectTargetsetRow = projRootIndex.row();
     cg.writeEntry("ProjectTargetSetRow", m_projectTargetsetRow);
     cg.writeEntry("NumTargets", targets.size());
 
@@ -487,6 +532,24 @@ void KateBuildView::writeSessionConfig(KConfigGroup &cg)
     }
 }
 
+/******************************************************************/
+void KateBuildView::readConfig()
+{
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("BuildConfig"));
+    m_addDiagnostics = config.readEntry(QStringLiteral("UseDiagnosticsOutput"), true);
+}
+
+/******************************************************************/
+static Diagnostic createDiagnostic(int line, int column, const QString &message, const DiagnosticSeverity &severity)
+{
+    Diagnostic d;
+    d.message = message;
+    d.source = DiagnosticsPrefix;
+    d.severity = severity;
+    d.range = KTextEditor::Range(KTextEditor::Cursor(line - 1, column - 1), 0);
+    return d;
+}
+
 /******************************************************************/
 void KateBuildView::addError(const KateBuildView::OutputLine &err)
 {
@@ -507,14 +570,19 @@ void KateBuildView::addError(const KateBuildView::OutputLine &err)
         severity = DiagnosticSeverity::Information;
     }
 
+    if (!m_addDiagnostics) {
+        return;
+    }
+
     // NOTE: Limit the number of items in the diagnostics view to 200 items.
     // Adding more items risks making the build slow. (standard item models are slow)
     if ((m_numErrors + m_numWarnings + m_numNotes) > 200) {
         return;
     }
-    updateDiagnostics(KateBuildView::createDiagnostic(err.lineNr, err.column, err.message, severity), uri);
+    updateDiagnostics(createDiagnostic(err.lineNr, err.column, err.message, severity), uri);
 }
 
+/******************************************************************/
 void KateBuildView::updateDiagnostics(Diagnostic diagnostic, const QUrl uri)
 {
     FileDiagnostics fd;
@@ -523,21 +591,12 @@ void KateBuildView::updateDiagnostics(Diagnostic diagnostic, const QUrl uri)
     Q_EMIT m_diagnosticsProvider.diagnosticsAdded(fd);
 }
 
+/******************************************************************/
 void KateBuildView::clearDiagnostics()
 {
     Q_EMIT m_diagnosticsProvider.requestClearDiagnostics(&m_diagnosticsProvider);
 }
 
-Diagnostic KateBuildView::createDiagnostic(int line, int column, const QString &message, const DiagnosticSeverity &severity)
-{
-    Diagnostic d;
-    d.message = message;
-    d.source = DiagnosticsPrefix;
-    d.severity = severity;
-    d.range = KTextEditor::Range(KTextEditor::Cursor(line - 1, column - 1), 0);
-    return d;
-}
-
 /******************************************************************/
 QUrl KateBuildView::docUrl()
 {
@@ -748,11 +807,11 @@ bool KateBuildView::buildCurrentTarget()
         return false;
     }
 
-    QString buildCmd = TargetModel::command(ind);
-    QString cmdName = TargetModel::cmdName(ind);
-    m_searchPaths = TargetModel::searchPaths(ind);
-    QString workDir = TargetModel::workDir(ind);
-    QString targetSet = TargetModel::targetName(ind);
+    QString buildCmd = ind.data(TargetModel::CommandRole).toString();
+    QString cmdName = ind.data(TargetModel::CommandNameRole).toString();
+    m_searchPaths = ind.data(TargetModel::SearchPathsRole).toStringList();
+    QString workDir = ind.data(TargetModel::WorkDirRole).toString();
+    QString targetSet = ind.data(TargetModel::TargetSetNameRole).toString();
 
     QString dir = workDir;
     if (workDir.isEmpty()) {
@@ -888,7 +947,7 @@ void KateBuildView::slotRunAfterBuild()
         // Nothing to run, and not a problem
         return;
     }
-    const QString workDir = TargetModel::workDir(idx);
+    const QString workDir = idx.data(TargetModel::WorkDirRole).toString();
     if (workDir.isEmpty()) {
         displayBuildResult(i18n("Cannot execute: %1 No working directory set.", runCmd), KTextEditor::Message::Warning);
         return;
@@ -1144,27 +1203,30 @@ void KateBuildView::slotAddTargetClicked()
     QString currCmd;
     QString currRun;
 
-    if (current.parent().isValid()) {
-        // we need the root item
-        current = current.parent();
-    }
     current = m_targetsUi->proxyModel.mapToSource(current);
-    QModelIndex index = m_targetsUi->targetsModel.addCommand(current, currName, currCmd, currRun);
+    QModelIndex index = m_targetsUi->targetsModel.addCommandAfter(current, currName, currCmd, currRun);
     index = m_targetsUi->proxyModel.mapFromSource(index);
     m_targetsUi->targetsView->setCurrentIndex(index);
+    if (index.data(TargetModel::IsProjectTargetRole).toBool()) {
+        saveProjectTargets();
+    }
 }
 
 /******************************************************************/
 void KateBuildView::targetSetNew()
 {
     m_targetsUi->targetFilterEdit->setText(QString());
-    QModelIndex index = m_targetsUi->targetsModel.addTargetSet(i18n("Target Set"), QString());
-    QModelIndex buildIndex = m_targetsUi->targetsModel.addCommand(index, i18n("Build"), DefBuildCmd, QString());
-    m_targetsUi->targetsModel.addCommand(index, i18n("Clean"), DefCleanCmd, QString());
-    m_targetsUi->targetsModel.addCommand(index, i18n("Config"), DefConfigCmd, QString());
-    m_targetsUi->targetsModel.addCommand(index, i18n("ConfigClean"), DefConfClean, QString());
+    QModelIndex currentIndex = m_targetsUi->proxyModel.mapToSource(m_targetsUi->targetsView->currentIndex());
+    QModelIndex index = m_targetsUi->targetsModel.insertTargetSetAfter(currentIndex, i18n("Target Set"), QString());
+    QModelIndex buildIndex = m_targetsUi->targetsModel.addCommandAfter(index, i18n("Build"), DefBuildCmd, QString());
+    m_targetsUi->targetsModel.addCommandAfter(index, i18n("Clean"), DefCleanCmd, QString());
+    m_targetsUi->targetsModel.addCommandAfter(index, i18n("Config"), DefConfigCmd, QString());
+    m_targetsUi->targetsModel.addCommandAfter(index, i18n("ConfigClean"), DefConfClean, QString());
     buildIndex = m_targetsUi->proxyModel.mapFromSource(buildIndex);
     m_targetsUi->targetsView->setCurrentIndex(buildIndex);
+    if (index.data(TargetModel::IsProjectTargetRole).toBool()) {
+        saveProjectTargets();
+    }
 }
 
 /******************************************************************/
@@ -1181,6 +1243,9 @@ void KateBuildView::targetOrSetCopy()
     }
     newIndex = m_targetsUi->proxyModel.mapFromSource(newIndex);
     m_targetsUi->targetsView->setCurrentIndex(newIndex);
+    if (newIndex.data(TargetModel::IsProjectTargetRole).toBool()) {
+        saveProjectTargets();
+    }
 }
 
 /******************************************************************/
@@ -1188,11 +1253,15 @@ void KateBuildView::targetDelete()
 {
     QModelIndex currentIndex = m_targetsUi->targetsView->currentIndex();
     currentIndex = m_targetsUi->proxyModel.mapToSource(currentIndex);
+    bool wasProjectTarget = currentIndex.data(TargetModel::IsProjectTargetRole).toBool();
     m_targetsUi->targetsModel.deleteItem(currentIndex);
 
     if (m_targetsUi->targetsModel.rowCount() == 0) {
         targetSetNew();
     }
+    if (wasProjectTarget) {
+        saveProjectTargets();
+    }
 }
 
 /******************************************************************/
@@ -1212,7 +1281,7 @@ void KateBuildView::slotPluginViewDeleted(const QString &name, QObject *)
     // remove view
     if (name == QLatin1String("kateprojectplugin")) {
         m_projectPluginView = nullptr;
-        m_targetsUi->targetsModel.deleteTargetSet(i18n("Project Plugin Targets"));
+        m_targetsUi->targetsModel.deleteProjectTargerts();
     }
 }
 
@@ -1223,17 +1292,67 @@ void KateBuildView::slotProjectMapChanged()
     if (!m_projectPluginView) {
         return;
     }
-    m_targetsUi->targetsModel.deleteTargetSet(i18n("Project Plugin Targets"));
+    m_targetsUi->targetsModel.deleteProjectTargerts();
     addProjectTarget();
 }
 
 /******************************************************************/
 void KateBuildView::addProjectTarget()
 {
-    // only do stuff with valid project
+    // only do stuff with a valid project
     if (!m_projectPluginView) {
         return;
     }
+
+    // Delete any old project plugin targets
+    m_targetsUi->targetsModel.deleteProjectTargerts();
+
+    const QModelIndex projRootIndex = m_targetsUi->targetsModel.projectRootIndex();
+    const QString projectsBaseDir = m_projectPluginView->property("projectBaseDir").toString();
+
+    // Read the targets from the override if available
+    const QString userOverride = projectsBaseDir + QStringLiteral("/.kateproject.build");
+    if (QFile::exists(userOverride)) {
+        // We have user modified commands
+        QFile file(userOverride);
+        if (file.open(QIODevice::ReadOnly)) {
+            bool targetAdded = false;
+            QJsonParseError error;
+            const QJsonDocument doc = QJsonDocument::fromJson(file.readAll(), &error);
+            file.close();
+            const QJsonObject obj = doc.object();
+            const QJsonArray sets = obj[QStringLiteral("target_sets")].toArray();
+            for (const auto &setVal : sets) {
+                const auto obj = setVal.toObject();
+                const QString setName = obj[QStringLiteral("name")].toString();
+                const QString workDir = obj[QStringLiteral("directory")].toString();
+                const QModelIndex setIdx = m_targetsUi->targetsModel.insertTargetSetAfter(projRootIndex, setName, workDir);
+                for (const auto &targetVals : obj[QStringLiteral("targets")].toArray()) {
+                    const auto tgtObj = targetVals.toObject();
+                    const QString name = tgtObj[QStringLiteral("name")].toString();
+                    const QString buildCmd = tgtObj[QStringLiteral("build_cmd")].toString();
+                    const QString runCmd = tgtObj[QStringLiteral("run_cmd")].toString();
+                    if (name.isEmpty()) {
+                        continue;
+                    }
+                    m_targetsUi->targetsModel.addCommandAfter(setIdx, name, buildCmd, runCmd);
+                    targetAdded = true;
+                }
+                if (targetAdded) {
+                    const auto index = m_targetsUi->proxyModel.mapFromSource(setIdx);
+                    if (index.isValid()) {
+                        m_targetsUi->targetsView->expand(index);
+                    }
+                }
+            }
+            if (targetAdded) {
+                return;
+                // The user file overrides the rest
+                // TODO maybe add heuristics for when to re-read the project data
+            }
+        }
+    }
+
     // query new project map
     QVariantMap projectMap = m_projectPluginView->property("projectMap").toMap();
 
@@ -1243,31 +1362,27 @@ void KateBuildView::addProjectTarget()
         return;
     }
 
-    // Delete any old project plugin targets
-    m_targetsUi->targetsModel.deleteTargetSet(i18n("Project Plugin Targets"));
-
     // handle build directory as relative to project file, if possible, see bug 413306
     QString projectsBuildDir = buildMap.value(QStringLiteral("directory")).toString();
-    const QString projectsBaseDir = m_projectPluginView->property("projectBaseDir").toString();
+    QString projectName = m_projectPluginView->property("projectName").toString();
     if (!projectsBaseDir.isEmpty()) {
         projectsBuildDir = QDir(projectsBaseDir).absoluteFilePath(projectsBuildDir);
     }
 
-    m_projectTargetsetRow = std::min(m_projectTargetsetRow, m_targetsUi->targetsModel.rowCount());
-    const QModelIndex set = m_targetsUi->targetsModel.insertTargetSet(m_projectTargetsetRow, i18n("Project Plugin Targets"), projectsBuildDir);
+    const QModelIndex set = m_targetsUi->targetsModel.insertTargetSetAfter(projRootIndex, projectName, projectsBuildDir);
     const QString defaultTarget = buildMap.value(QStringLiteral("default_target")).toString();
 
     const QVariantList targetsets = buildMap.value(QStringLiteral("targets")).toList();
     for (const QVariant &targetVariant : targetsets) {
-        QVariantMap targetMap = targetVariant.toMap();
-        QString tgtName = targetMap[QStringLiteral("name")].toString();
-        QString buildCmd = targetMap[QStringLiteral("build_cmd")].toString();
-        QString runCmd = targetMap[QStringLiteral("run_cmd")].toString();
+        const QVariantMap targetMap = targetVariant.toMap();
+        const QString tgtName = targetMap[QStringLiteral("name")].toString();
+        const QString buildCmd = targetMap[QStringLiteral("build_cmd")].toString();
+        const QString runCmd = targetMap[QStringLiteral("run_cmd")].toString();
 
         if (tgtName.isEmpty() || buildCmd.isEmpty()) {
             continue;
         }
-        QPersistentModelIndex idx = m_targetsUi->targetsModel.addCommand(set, tgtName, buildCmd, runCmd);
+        QPersistentModelIndex idx = m_targetsUi->targetsModel.addCommandAfter(set, tgtName, buildCmd, runCmd);
         if (tgtName == defaultTarget) {
             // A bit of backwards compatibility, move the "default" target to the top
             while (idx.row() > 0) {
@@ -1276,25 +1391,57 @@ void KateBuildView::addProjectTarget()
         }
     }
 
-    if (!set.model()->index(0, 0, set).isValid()) {
-        QString buildCmd = buildMap.value(QStringLiteral("build")).toString();
-        QString cleanCmd = buildMap.value(QStringLiteral("clean")).toString();
-        QString quickCmd = buildMap.value(QStringLiteral("quick")).toString();
-        if (!buildCmd.isEmpty()) {
-            // we have loaded an "old" project file (<= 4.12)
-            m_targetsUi->targetsModel.addCommand(set, i18n("build"), buildCmd, QString());
-        }
-        if (!cleanCmd.isEmpty()) {
-            m_targetsUi->targetsModel.addCommand(set, i18n("clean"), cleanCmd, QString());
-        }
-        if (!quickCmd.isEmpty()) {
-            m_targetsUi->targetsModel.addCommand(set, i18n("quick"), quickCmd, QString());
-        }
-    }
     const auto index = m_targetsUi->proxyModel.mapFromSource(set);
     if (index.isValid()) {
         m_targetsUi->targetsView->expand(index);
     }
+
+    // FIXME read CMakePresets.json for more build target sets
+}
+
+/******************************************************************/
+void KateBuildView::saveProjectTargets()
+{
+    // only do stuff with a valid project
+    if (!m_projectPluginView) {
+        return;
+    }
+
+    const QString projectsBaseDir = m_projectPluginView->property("projectBaseDir").toString();
+    const QString userOverride = projectsBaseDir + QStringLiteral("/.kateproject.build");
+
+    QFile file(userOverride);
+    if (!file.open(QIODevice::ReadWrite | QIODevice::Truncate)) {
+        displayMessage(i18n("Cannot save build targets in: %1", userOverride), KTextEditor::Message::Error);
+        return;
+    }
+
+    const QList<TargetModel::TargetSet> targets = m_targetsUi->targetsModel.projectTargetSets();
+
+    QJsonObject root;
+    root[QStringLiteral("Auto_generated")] = QStringLiteral("This file is auto-generated. Any extra tags or formatting will be lost");
+
+    QJsonArray setArray;
+    for (const auto &set : targets) {
+        QJsonObject setObj;
+        setObj[QStringLiteral("name")] = set.name;
+        setObj[QStringLiteral("directory")] = set.workDir;
+        QJsonArray cmdArray;
+        for (const auto &cmd : std::as_const(set.commands)) {
+            QJsonObject cmdObj;
+            cmdObj[QStringLiteral("name")] = cmd.name;
+            cmdObj[QStringLiteral("build_cmd")] = cmd.buildCmd;
+            cmdObj[QStringLiteral("runCmd")] = cmd.runCmd;
+            cmdArray.append(cmdObj);
+        }
+        setObj[QStringLiteral("targets")] = cmdArray;
+        setArray.append(setObj);
+    }
+    root[QStringLiteral("target_sets")] = setArray;
+    QJsonDocument doc(root);
+
+    file.write(doc.toJson());
+    file.close();
 }
 
 /******************************************************************/
