@@ -45,12 +45,12 @@ class KeyboardMacrosPlugin : public KTextEditor::Plugin
     Macro m_macro;
     QString m_storage;
     bool m_namedMacrosLoaded = false;
-    QMap<QString, Macro> m_namedMacros;
+    std::map<QString, Macro> m_namedMacros;
     QSet<QString> m_wipedMacros;
 
     // Plugin creation and destruction
 public:
-    explicit KeyboardMacrosPlugin(QObject *parent = nullptr, const QList<QVariant> & = QList<QVariant>());
+    explicit KeyboardMacrosPlugin(QObject *parent = nullptr, const QVariantList & = QVariantList());
     ~KeyboardMacrosPlugin() override;
     QObject *createView(KTextEditor::MainWindow *mainWindow) override;
 
