@@ -48,7 +48,7 @@ K_PLUGIN_FACTORY_WITH_JSON(KateKonsolePluginFactory, "katekonsoleplugin.json", r
 
 static const QStringList s_escapeExceptions{QStringLiteral("vi"), QStringLiteral("vim"), QStringLiteral("nvim"), QStringLiteral("git")};
 
-KateKonsolePlugin::KateKonsolePlugin(QObject *parent, const QList<QVariant> &)
+KateKonsolePlugin::KateKonsolePlugin(QObject *parent, const QVariantList &)
     : KTextEditor::Plugin(parent)
     , m_previousEditorEnv(qgetenv("EDITOR"))
 {
@@ -582,7 +582,6 @@ KateKonsoleConfigPage::KateKonsoleConfigPage(QWidget *parent, KateKonsolePlugin
 {
     QVBoxLayout *lo = new QVBoxLayout(this);
     lo->setSpacing(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
-    lo->setContentsMargins(0, 0, 0, 0);
 
     cbAutoSyncronize = new QCheckBox(i18n("&Automatically synchronize the terminal with the current document when possible"), this);
     lo->addWidget(cbAutoSyncronize);
