@@ -27,6 +27,7 @@
 #include <QContextMenuEvent>
 #include <QDialog>
 #include <QEvent>
+#include <QGuiApplication>
 #include <QHeaderView>
 #include <QInputDialog>
 #include <QInputMethodEvent>
@@ -323,6 +324,7 @@ void GitWidget::init()
 
     m_filterLineEdit = new QLineEdit(this);
     m_filterLineEdit->setPlaceholderText(i18n("Filter..."));
+    m_filterLineEdit->setProperty("_breeze_borders_sides", QVariant::fromValue(QFlags{Qt::TopEdge}));
     layout->addWidget(m_filterLineEdit);
 
     m_model = new GitStatusModel(this);
@@ -339,6 +341,7 @@ void GitWidget::init()
     m_treeView->installEventFilter(this);
     m_treeView->setRootIsDecorated(false);
     m_treeView->setAllColumnsShowFocus(true);
+    m_treeView->setProperty("_breeze_borders_sides", QVariant::fromValue(QFlags{Qt::TopEdge}));
     m_treeView->expandAll();
 
     if (m_treeView->style()) {
@@ -861,20 +864,24 @@ void GitWidget::handleClick(const QModelIndex &idx, ClickAction clickAction)
 
 void GitWidget::treeViewSingleClicked(const QModelIndex &idx)
 {
-    handleClick(idx, m_pluginView->plugin()->singleClickAcion());
+    if (qGuiApp->keyboardModifiers() == Qt::NoModifier) {
+        handleClick(idx, m_pluginView->plugin()->singleClickAcion());
+    }
 }
 
 void GitWidget::treeViewDoubleClicked(const QModelIndex &idx)
 {
-    handleClick(idx, m_pluginView->plugin()->doubleClickAcion());
+    if (qGuiApp->keyboardModifiers() == Qt::NoModifier) {
+        handleClick(idx, m_pluginView->plugin()->doubleClickAcion());
+    }
 }
 
 void GitWidget::parseStatusReady()
 {
     // Remember collapse/expand state
     // The default is expanded, so only add here which should be not expanded
-    QMap<int, bool> nodeIsExpanded;
-    nodeIsExpanded.insert(GitStatusModel::NodeUntrack, false);
+    std::map<int, bool> nodeIsExpanded;
+    nodeIsExpanded[GitStatusModel::NodeUntrack] = false;
 
     const auto *model = m_treeView->model();
     for (int i = 0; i < model->rowCount(); ++i) {
@@ -896,7 +903,7 @@ void GitWidget::parseStatusReady()
             continue;
         }
         const auto t = index.data(GitStatusModel::TreeItemType).toInt();
-        if (!nodeIsExpanded.contains(t) || nodeIsExpanded[t]) {
+        if (nodeIsExpanded.find(t) == nodeIsExpanded.end() || nodeIsExpanded[t]) {
             m_treeView->expand(index);
         } else {
             m_treeView->collapse(index);
