@@ -7,6 +7,7 @@
 
 #include "kateapp.h"
 
+#include "katemainwindow.h"
 #include "kateviewmanager.h"
 
 #include <kcoreaddons_version.h>
@@ -35,12 +36,12 @@
 #endif
 
 #ifdef WITH_KUSERFEEDBACK
-#include <KUserFeedbackQt6/ApplicationVersionSource>
-#include <KUserFeedbackQt6/PlatformInfoSource>
-#include <KUserFeedbackQt6/QtVersionSource>
-#include <KUserFeedbackQt6/ScreenInfoSource>
-#include <KUserFeedbackQt6/StartCountSource>
-#include <KUserFeedbackQt6/UsageTimeSource>
+#include <KUserFeedback/ApplicationVersionSource>
+#include <KUserFeedback/PlatformInfoSource>
+#include <KUserFeedback/QtVersionSource>
+#include <KUserFeedback/ScreenInfoSource>
+#include <KUserFeedback/StartCountSource>
+#include <KUserFeedback/UsageTimeSource>
 #endif
 
 #include <QApplication>
@@ -666,6 +667,27 @@ bool KateApp::openInput(const QString &text, const QString &encoding)
     return doc->setText(text);
 }
 
+KTextEditor::MainWindow *KateApp::activeMainWindow()
+{
+    // either return wrapper or nullptr
+    if (KateMainWindow *a = activeKateMainWindow()) {
+        return a->wrapper();
+    }
+    return nullptr;
+}
+
+QList<KTextEditor::MainWindow *> KateApp::mainWindows()
+{
+    // assemble right list
+    QList<KTextEditor::MainWindow *> windows;
+    windows.reserve(m_mainWindows.size());
+
+    for (const auto mainWindow : std::as_const(m_mainWindows)) {
+        windows.push_back(mainWindow->wrapper());
+    }
+    return windows;
+}
+
 KateMainWindow *KateApp::newMainWindow(KConfig *sconfig_, const QString &sgroup_, bool userTriggered)
 {
     KConfig *sconfig = sconfig_ ? sconfig_ : KSharedConfig::openConfig().data();
@@ -693,7 +715,7 @@ KateMainWindow *KateApp::activeKateMainWindow()
         return nullptr;
     }
 
-    int n = m_mainWindows.indexOf(static_cast<KateMainWindow *>((static_cast<QApplication *>(QCoreApplication::instance())->activeWindow())));
+    int n = m_mainWindows.indexOf(qApp->activeWindow());
 
     if (n < 0) {
         n = 0;
