@@ -99,112 +99,6 @@ KateConfigDialog::KateConfigDialog(KateMainWindow *parent)
     connect(buttonBox()->button(QDialogButtonBox::Help), &QPushButton::clicked, this, &KateConfigDialog::slotHelp);
 }
 
-template<typename WidgetType>
-QList<QWidget *> hasMatchingText(const QString &text, QWidget *page)
-{
-    QList<QWidget *> ret;
-    const auto widgets = page->findChildren<WidgetType *>();
-    for (auto label : widgets) {
-        if (label->text().contains(text, Qt::CaseInsensitive)) {
-            ret << label;
-        }
-    }
-    return ret;
-}
-
-template<>
-QList<QWidget *> hasMatchingText<QComboBox>(const QString &text, QWidget *page)
-{
-    QList<QWidget *> ret;
-    const auto comboxBoxes = page->findChildren<QComboBox *>();
-    for (auto cb : comboxBoxes) {
-        if (cb->findText(text, Qt::MatchFlag::MatchContains) != -1) {
-            ret << cb;
-        }
-    }
-    return ret;
-}
-
-template<typename...>
-struct FindChildrenHelper {
-    static QList<QWidget *> hasMatchingTextForTypes(const QString &, QWidget *)
-    {
-        return {};
-    }
-};
-
-template<typename First, typename... Rest>
-struct FindChildrenHelper<First, Rest...> {
-    static QList<QWidget *> hasMatchingTextForTypes(const QString &text, QWidget *page)
-    {
-        return hasMatchingText<First>(text, page) << FindChildrenHelper<Rest...>::hasMatchingTextForTypes(text, page);
-    }
-};
-
-class SearchMatchOverlay : public QWidget
-{
-public:
-    SearchMatchOverlay(QWidget *parent, int tabIdx = -1)
-        : QWidget(parent)
-        , m_tabIdx(tabIdx)
-    {
-        setAttribute(Qt::WA_TransparentForMouseEvents, true);
-        resize_impl();
-        parent->installEventFilter(this);
-
-        show();
-        raise();
-    }
-
-    void doResize()
-    {
-        // trigger it delayed just to be safe as we will be calling
-        // it in response to Resize sometimes
-        QMetaObject::invokeMethod(this, &SearchMatchOverlay::resize_impl, Qt::QueuedConnection);
-    }
-
-    void resize_impl()
-    {
-        if (m_tabIdx >= 0) {
-            auto tabBar = qobject_cast<QTabBar *>(parent());
-            if (!tabBar) {
-                setVisible(false);
-                return;
-            }
-            const QRect r = tabBar->tabRect(m_tabIdx);
-            if (geometry() != r) {
-                setGeometry(r);
-            }
-            return;
-        }
-
-        if (auto p = qobject_cast<QWidget *>(parent()); p && size() != p->size()) {
-            resize(p->size());
-        }
-    }
-
-    bool eventFilter(QObject *o, QEvent *e) override
-    {
-        if (parent() && o == parent() && (e->type() == QEvent::Resize || e->type() == QEvent::Show)) {
-            doResize();
-        }
-        return QWidget::eventFilter(o, e);
-    }
-
-protected:
-    void paintEvent(QPaintEvent *e) override
-    {
-        QPainter p(this);
-        p.setClipRegion(e->region());
-        QColor c = palette().brush(QPalette::Active, QPalette::Highlight).color();
-        c.setAlpha(110);
-        p.fillRect(rect(), c);
-    }
-
-private:
-    int m_tabIdx = -1;
-};
-
 QSize KateConfigDialog::sizeHint() const
 {
     // start with a bit enlarged default size hint to minimize changes of useless scrollbars
@@ -229,7 +123,6 @@ void KateConfigDialog::addBehaviorPage()
     item->setIcon(QIcon::fromTheme(QStringLiteral("preferences-system-windows-behavior")));
 
     QVBoxLayout *layout = new QVBoxLayout(generalFrame);
-    layout->setContentsMargins(0, 0, 0, 0);
 
     // GROUP with the one below: "Behavior"
     QGroupBox *buttonGroup = new QGroupBox(i18n("&Behavior"), generalFrame);
@@ -605,18 +498,19 @@ void KateConfigDialog::addPluginPage(KTextEditor::Plugin *plugin)
 
 void KateConfigDialog::removePluginPage(KTextEditor::Plugin *plugin)
 {
-    QList<KPageWidgetItem *> remove;
+    std::vector<KPageWidgetItem *> remove;
     for (QHash<KPageWidgetItem *, PluginPageListItem>::const_iterator it = m_pluginPages.constBegin(); it != m_pluginPages.constEnd(); ++it) {
         const PluginPageListItem &pli = it.value();
 
         if (pli.plugin == plugin) {
-            remove.append(it.key());
+            remove.push_back(it.key());
         }
     }
 
-    qCDebug(LOG_KATE) << remove.count();
-    while (!remove.isEmpty()) {
-        KPageWidgetItem *wItem = remove.takeLast();
+    qCDebug(LOG_KATE) << remove.size();
+    while (!remove.empty()) {
+        KPageWidgetItem *wItem = remove.back();
+        remove.pop_back();
         PluginPageListItem item = m_pluginPages.take(wItem);
         m_allPages.remove(wItem);
         delete item.pluginPage;
@@ -737,7 +631,7 @@ void KateConfigDialog::slotApply()
     }
 
     // apply ktexteditor pages
-    for (KTextEditor::ConfigPage *page : qAsConst(m_editorPages)) {
+    for (KTextEditor::ConfigPage *page : m_editorPages) {
         page->apply();
     }
 
