@@ -548,6 +548,10 @@ void KateMainWindow::setupActions()
 
 void KateMainWindow::setupDiagnosticsView(KConfig *sconfig)
 {
+    if (KateApp::isKWrite()) {
+        return;
+    }
+
     m_diagView = DiagnosticsView::instance(wrapper());
     m_diagView->readSessionConfig(KConfigGroup(sconfig, QStringLiteral("Kate Diagnostics")));
     // See comment in DiagnosticsView::DiagnosticsView()
@@ -671,12 +675,11 @@ bool KateMainWindow::queryClose_internal(KTextEditor::Document *doc, KateMainWin
                                 modifiedDocuments.end());
     }
 
-    // Remove all docs for which doc::queryClose == true. These can be untitled
-    // docs for e.g.,
+    // Remove all documents that can be closed without user confirmation
     modifiedDocuments.erase(std::remove_if(modifiedDocuments.begin(),
                                            modifiedDocuments.end(),
                                            [](KTextEditor::Document *d) {
-                                               return d->queryClose();
+                                               return !d->isModified() || (d->isEmpty() && d->url().isEmpty());
                                            }),
                             modifiedDocuments.end());
 
@@ -950,7 +953,7 @@ void KateMainWindow::slotDropEvent(QDropEvent *event)
                                                     KGuiItem(i18nc("@action:button", "Open All Files"), QStringLiteral("document-open")),
                                                     KStandardGuiItem::cancel())
                     == KMessageBox::PrimaryAction) {
-                    KIO::ListJob *list_job = KIO::listRecursive(url, KIO::DefaultFlags, false);
+                    KIO::ListJob *list_job = KIO::listRecursive(url, KIO::DefaultFlags, KIO::ListJob::ListFlags{});
                     connect(list_job, &KIO::ListJob::entries, this, &KateMainWindow::slotListRecursiveEntries);
                 }
             } else {
@@ -1492,9 +1495,10 @@ void KateMainWindow::slotQuickOpen()
     /**
      * show quick open and pass focus to it
      */
-    KateQuickOpen quickOpen(this);
-    centralWidget()->setFocusProxy(&quickOpen);
-    quickOpen.exec();
+    KateQuickOpen *quickOpen = new KateQuickOpen(this);
+    centralWidget()->setFocusProxy(quickOpen);
+    quickOpen->raise();
+    quickOpen->show();
 }
 
 QWidget *KateMainWindow::createToolView(KTextEditor::Plugin *plugin,
