@@ -24,9 +24,12 @@
 #include <QApplication>
 #include <QContextMenuEvent>
 #include <QDomDocument>
+#include <QDrag>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QMenu>
+#include <QMimeData>
+#include <QRubberBand>
 #include <QSizePolicy>
 #include <QStackedWidget>
 #include <QStyle>
@@ -371,13 +374,13 @@ KMultiTabBarTab *MultiTabBar::addTab(int id, ToolView *tv)
     m_stack->addWidget(tv);
     KMultiTabBarTab *newTab;
 
-    if (m_tabList.contains(id)) {
+    if (std::find(m_tabList.begin(), m_tabList.end(), id) != m_tabList.end()) {
         // We are in session restore
         newTab = m_multiTabBar->tab(id);
         newTab->setIcon(tv->icon);
         newTab->setText(tv->text);
     } else {
-        m_tabList.append(id);
+        m_tabList.push_back(id);
         m_multiTabBar->appendTab(tv->icon, id, tv->text);
         newTab = m_multiTabBar->tab(id);
     }
@@ -392,7 +395,7 @@ KMultiTabBarTab *MultiTabBar::addTab(int id, ToolView *tv)
 int MultiTabBar::addBlankTab()
 {
     int id = m_sb->nextId();
-    m_tabList.append(id);
+    m_tabList.push_back(id);
     m_multiTabBar->appendTab(QIcon(), id, QStringLiteral("placeholder"));
     return id;
 }
@@ -410,7 +413,7 @@ void MultiTabBar::tabClicked(int id)
 
 void MultiTabBar::removeBlankTab(int id)
 {
-    m_tabList.removeAll(id);
+    m_tabList.erase(std::remove(m_tabList.begin(), m_tabList.end(), id), m_tabList.end());
     m_multiTabBar->removeTab(id);
     if (tabCount() == 0) {
         m_activeTab = 0;
@@ -420,7 +423,7 @@ void MultiTabBar::removeBlankTab(int id)
 
 void MultiTabBar::removeTab(int id)
 {
-    m_tabList.removeAll(id);
+    m_tabList.erase(std::remove(m_tabList.begin(), m_tabList.end(), id), m_tabList.end());
     m_multiTabBar->removeTab(id);
     ToolView *tv = m_sb->m_idToWidget.at(id);
     m_sb->m_widgetToTabBar.erase(tv);
@@ -446,6 +449,55 @@ void MultiTabBar::removeTab(int id)
     }
 }
 
+void MultiTabBar::reorderTab(int id, KMultiTabBarTab *before)
+{
+    // can't find source id?
+    auto it = std::find(m_tabList.begin(), m_tabList.end(), id);
+    if (it == m_tabList.end()) {
+        return;
+    }
+    int idIdx = std::distance(m_tabList.begin(), it);
+    it = before ? std::find(m_tabList.begin(), m_tabList.end(), before->id()) : m_tabList.end();
+    if (before && it == m_tabList.end()) {
+        // can't find before id?
+        return;
+    }
+    // before == null, idx will be the last idx
+    int beforeIdx = it == m_tabList.end() ? m_tabList.size() - 1 : std::distance(m_tabList.begin(), it);
+    if (idIdx == beforeIdx) {
+        return;
+    }
+
+    int start = std::min(idIdx, beforeIdx);
+
+    // copy because after removeTab `before` will be invalid
+    const int beforeId = before ? before->id() : -1;
+
+    // Remove the actual tabs
+    for (size_t i = start; i < m_tabList.size(); ++i) {
+        auto oldTab = m_multiTabBar->tab(m_tabList[i]);
+        oldTab->removeEventFilter(m_sb);
+        m_multiTabBar->removeTab(m_tabList[i]);
+    }
+
+    // reorder the tab list
+    // erase old position
+    m_tabList.erase(std::remove(m_tabList.begin(), m_tabList.end(), id), m_tabList.end());
+    // find new position and insert
+    it = before ? std::find(m_tabList.begin(), m_tabList.end(), beforeId) : m_tabList.end();
+    m_tabList.insert(it, id);
+
+    // re-add tabs
+    for (size_t i = start; i < m_tabList.size(); ++i) {
+        auto tabId = m_tabList[i];
+        ToolView *tv = m_sb->m_idToWidget.at(tabId);
+        m_multiTabBar->appendTab(tv->icon, tabId, tv->text);
+        auto newTab = m_multiTabBar->tab(tabId);
+        newTab->installEventFilter(m_sb);
+        connect(newTab, &KMultiTabBarTab::clicked, this, &MultiTabBar::tabClicked);
+    }
+}
+
 void MultiTabBar::showToolView(int id)
 {
     setTabActive(id, true);
@@ -524,8 +576,12 @@ Sidebar::Sidebar(KMultiTabBar::KMultiTabBarPosition pos, QSplitter *sp, MainWind
     , m_ownSplit(new QSplitter(sp))
     , m_ownSplitIndex(sp->indexOf(m_ownSplit))
     , m_lastSize(200) // Default used when no session to restore is around
+    , m_dropIndicator(new QRubberBand(QRubberBand::Rectangle, mainwin))
+    , m_internalDropIndicator(new QRubberBand(QRubberBand::Rectangle, mainwin))
 {
     setChildrenCollapsible(false);
+    setAcceptDrops(true);
+    connect(this, &Sidebar::destroyed, m_dropIndicator, &QObject::deleteLater);
 
     if (isVertical()) {
         m_ownSplit->setOrientation(Qt::Vertical);
@@ -660,6 +716,11 @@ QSize Sidebar::sizeHint() const
     return minimumSizeHint();
 }
 
+QSize Sidebar::minimumSizeHint() const
+{
+    return isVisible() ? QSplitter::minimumSizeHint() : QSize{0, 0};
+}
+
 MultiTabBar *Sidebar::insertTabBar(int idx /* = -1*/)
 {
     auto *newBar = new MultiTabBar(m_tabBarPosition, this, idx);
@@ -1081,22 +1142,174 @@ bool Sidebar::eventFilter(QObject *obj, QEvent *ev)
         }
     } else if (ev->type() == QEvent::MouseButtonPress) {
         QMouseEvent *e = static_cast<QMouseEvent *>(ev);
-        // The non-tab area of the sidebar is clicked (well, pressed) => toggle collapse/expand
-        if (e->button() == Qt::LeftButton) {
-            if (obj->property("is-multi-tabbar").toBool()) {
-                if (isCollapsed()) {
-                    updateSidebar();
-                } else {
-                    collapseSidebar();
+        if (qobject_cast<MultiTabBar *>(obj)) {
+            // The non-tab area of the sidebar is clicked (well, pressed) => toggle collapse/expand
+            if (e->button() == Qt::LeftButton) {
+                if (obj->property("is-multi-tabbar").toBool()) {
+                    if (isCollapsed()) {
+                        updateSidebar();
+                    } else {
+                        collapseSidebar();
+                    }
+                    return true;
                 }
-                return true;
             }
+        } else if (auto btn = qobject_cast<KMultiTabBarTab *>(obj) && e->button() == Qt::LeftButton) {
+            dragStartPos = e->pos();
+        }
+    } else if (!dragStartPos.isNull() && ev->type() == QEvent::MouseMove) {
+        QMouseEvent *e = static_cast<QMouseEvent *>(ev);
+        auto tab = qobject_cast<KMultiTabBarTab *>(obj);
+        if (tab && (e->pos() - dragStartPos).manhattanLength() >= QApplication::startDragDistance()) {
+            // start drag
+            QPixmap pixmap = tab->grab();
+            QDrag *drag = new QDrag(this);
+            auto md = new QMimeData();
+            ToolView *toolView = m_idToWidget[tab->id()];
+            Q_ASSERT(toolView);
+            md->setProperty("toolviewToMove", QVariant::fromValue(toolView));
+            drag->setMimeData(md);
+            drag->setPixmap(pixmap);
+            drag->setHotSpot(dragStartPos);
+            dragStartPos = {};
+            connect(drag, &QObject::destroyed, this, &Sidebar::dragEnded);
+
+            Q_EMIT dragStarted();
+
+            drag->exec(Qt::MoveAction);
+            return true;
         }
     }
 
     return false;
 }
 
+void Sidebar::dragEnterEvent(QDragEnterEvent *e)
+{
+    if (e->proposedAction() != Qt::MoveAction) {
+        return;
+    }
+
+    if (e->source() == this) {
+        if (toolviewCount() == 1) {
+            // only 1 toolview? Nothing to reorder then
+            return;
+        }
+        m_internalDropIndicator->raise();
+        if (m_internalDropIndicator->geometry() != geometry()) {
+            m_internalDropIndicator->setGeometry(geometry());
+        }
+
+        if (isVertical()) {
+            m_internalDropIndicator->setFixedHeight(4);
+        } else {
+            m_internalDropIndicator->setFixedWidth(4);
+        }
+
+        auto mimeData = e->mimeData();
+        ToolView *toolview = mimeData->property("toolviewToMove").value<ToolView *>();
+        QWidget *tab = tabButtonForToolview(toolview);
+        if (!tab || !toolview) {
+            return;
+        }
+
+        const QPoint tabPos = tab->pos();
+        auto globalPos = mapToGlobal(tabPos);
+        auto pos = m_mainWin->mapFromGlobal(globalPos);
+        m_internalDropIndicator->move(pos);
+        m_internalDropIndicator->show();
+    } else { // Show Drop Indicator
+        m_dropIndicator->raise();
+        if (m_dropIndicator->geometry() != geometry()) {
+            m_dropIndicator->setGeometry(geometry());
+        }
+        auto globalPos = mapToGlobal(pos());
+        auto indicatorPos = m_dropIndicator->mapFromGlobal(globalPos);
+        if (indicatorPos != m_dropIndicator->pos()) {
+            m_dropIndicator->move(indicatorPos);
+        }
+
+        m_dropIndicator->show();
+    }
+    e->acceptProposedAction();
+}
+
+void Sidebar::dropEvent(QDropEvent *e)
+{
+    auto mimeData = e->mimeData();
+    m_dropIndicator->hide();
+    m_internalDropIndicator->hide();
+
+    if (!mimeData) {
+        return;
+    }
+    ToolView *toolview = mimeData->property("toolviewToMove").value<ToolView *>();
+    if (!toolview) {
+        return;
+    }
+
+    if (e->source() == this) {
+        // Re-ordering tabs
+        auto sourceTab = qobject_cast<KMultiTabBarTab *>(tabButtonForToolview(toolview));
+        if (!sourceTab) {
+            return;
+        }
+        // destTab might be null, which means we will just append to the end
+        auto destTab = qobject_cast<KMultiTabBarTab *>(childAt(e->position().toPoint()));
+        auto tabbar = m_widgetToTabBar[toolview];
+        tabbar->reorderTab(sourceTab->id(), destTab);
+    } else {
+        m_mainWin->moveToolView(toolview, position(), /*isDND=*/true);
+        m_mainWin->showToolView(toolview);
+    }
+
+    e->accept();
+}
+
+void Sidebar::dragMoveEvent(QDragMoveEvent *e)
+{
+    if (e->source() != this || toolviewCount() == 1) {
+        // We only handle drag move if we are moving on source sidebar
+        // and if there is only 1 toolview, there is nothing to reorder
+        return;
+    }
+
+    auto *tab = qobject_cast<KMultiTabBarTab *>(childAt(e->position().toPoint()));
+    if (tab) {
+        // moving over a tab? show the indicator at tab start
+        const QPoint tabPos = tab->pos();
+        auto globalPos = mapToGlobal(tabPos);
+        auto pos = m_mainWin->mapFromGlobal(globalPos);
+        m_internalDropIndicator->move(pos);
+    } else {
+        // Otherwise show at the end of tab list
+        auto mimeData = e->mimeData();
+        ToolView *toolview = mimeData->property("toolviewToMove").value<ToolView *>();
+        if (!toolview) {
+            return;
+        }
+        auto tabbar = m_widgetToTabBar[toolview];
+        auto lastTabId = tabbar->tabList().back();
+        auto tab = tabbar->tabBar()->tab(lastTabId);
+
+        QPoint tabPos = tab->pos();
+        if (isVertical()) {
+            tabPos.setY(tabPos.y() + tab->height());
+        } else {
+            tabPos.setX(tabPos.x() + tab->width());
+        }
+        auto globalPos = mapToGlobal(tabPos);
+        auto pos = m_mainWin->mapFromGlobal(globalPos);
+        m_internalDropIndicator->move(pos);
+    }
+}
+
+void Sidebar::dragLeaveEvent(QDragLeaveEvent *)
+{
+    m_internalDropIndicator->hide();
+    m_dropIndicator->hide();
+}
+
 void Sidebar::setVisible(bool visible)
 {
     // visible==true means show-request
@@ -1335,6 +1548,11 @@ MainWindow::MainWindow(QWidget *parent)
     m_sidebars[KMultiTabBar::Right] = std::make_unique<Sidebar>(KMultiTabBar::Right, m_hSplitter, this, hb);
     hlayout->addWidget(m_sidebars[KMultiTabBar::Right].get());
 
+    auto separator = new QFrame(this);
+    separator->setFrameShape(QFrame::HLine);
+    separator->setFixedHeight(1);
+    toplevelVBox->addWidget(separator);
+
     // bottom side bar spans full windows, include status bar, too
     m_sidebars[KMultiTabBar::Bottom] = std::make_unique<Sidebar>(KMultiTabBar::Bottom, m_vSplitter, this, vb);
     m_bottomSidebarLayout = new QHBoxLayout;
@@ -1354,6 +1572,26 @@ MainWindow::MainWindow(QWidget *parent)
 
     for (const auto &sidebar : m_sidebars) {
         connect(sidebar.get(), &Sidebar::sigShowPluginConfigPage, this, &MainWindow::sigShowPluginConfigPage);
+
+        // Drag/Drop
+        connect(sidebar.get(), &Sidebar::dragStarted, this, [this]() {
+            for (const auto &sb : m_sidebars) {
+                m_dragState.m_wasVisible[(int)sb->position()] = sb->isVisible();
+                if (!sb->isVisible()) {
+                    sb->setMinimumSize({50, 50});
+                    sb->QSplitter::setVisible(true);
+                }
+            }
+        });
+        connect(sidebar.get(), &Sidebar::dragEnded, this, [this]() {
+            for (const auto &sb : m_sidebars) {
+                bool wasVisible = m_dragState.m_wasVisible[(int)sb->position()];
+                if (!wasVisible) {
+                    sb->setMinimumSize({0, 0});
+                    sb->QSplitter::setVisible(false);
+                }
+            }
+        });
     }
 }
 
@@ -1485,7 +1723,7 @@ KMultiTabBar::KMultiTabBarStyle MainWindow::toolViewStyle() const
     return m_sidebars[KMultiTabBar::Top]->tabStyle();
 }
 
-bool MainWindow::moveToolView(ToolView *widget, KMultiTabBar::KMultiTabBarPosition pos)
+bool MainWindow::moveToolView(ToolView *widget, KMultiTabBar::KMultiTabBarPosition pos, bool isDND)
 {
     if (!widget || widget->mainWindow() != this) {
         return false;
@@ -1497,8 +1735,27 @@ bool MainWindow::moveToolView(ToolView *widget, KMultiTabBar::KMultiTabBarPositi
         pos = static_cast<KMultiTabBar::KMultiTabBarPosition>(cg.readEntry(QStringLiteral("Kate-MDI-ToolView-%1-Position").arg(widget->id), int(pos)));
     }
 
+    if (isDND) {
+        // Ensure that after dropping, sidebar becomes visiblee
+        // Sidebar might have been hidden because it was empty i.e.,
+        // had no toolviews
+        m_dragState.m_wasVisible[pos] = true;
+
+        // If source sidebar contains only 1 toolview, then hide it
+        // because after the drop it will have nothing.
+        auto source = widget->sidebar();
+        if (source->toolviewCount() == 1) {
+            m_dragState.m_wasVisible[source->position()] = false;
+        }
+    }
+
     m_sidebars[pos]->addToolView(widget->icon, widget->text, widget->id, widget);
 
+    if (isDND) {
+        // reduce min size so that sidebar can adjust size properly
+        m_sidebars[pos]->setMinimumSize({0, 0});
+    }
+
     return true;
 }
 
